@@ -1,24 +1,29 @@
-# Copyright (C) 2018  Eddie Antonio Santos <easantos@ualberta.ca>
+# Copyright © 2018–2021 National Research Council Canada
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining a copy of
+# this software and associated documentation files (the "Software"), to deal in
+# the Software without restriction, including without limitation the rights to
+# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
+# the Software, and to permit persons to whom the Software is furnished to do so,
+# subject to the following conditions:
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
+# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
+# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
 
 import re
 from collections import ChainMap
 from unicodedata import normalize
 
 __all__ = ["sro2syllabics", "syllabics2sro"]
-__version__ = "2020.5.11"
+__version__ = "2021.4.15"
 
 
 DEFAULT_HYPHENS = "\N{NARROW NO-BREAK SPACE}"
@@ -183,7 +188,7 @@ sro2syllabics_lookup = {
     "swô": "ᓿ",
     "swa": "ᔁ",
     "swâ": "ᔃ",
-    "y": "ᕀ",
+    "y": "ᐩ",
     "yê": "ᔦ",
     "yi": "ᔨ",
     "yî": "ᔩ",
@@ -323,7 +328,7 @@ def sro2syllabics(sro: str, hyphens: str = DEFAULT_HYPHENS, sandhi: bool = True)
     >>> sro2syllabics('Maskêkosihk trail')
     'ᒪᐢᑫᑯᓯᕽ trail'
     >>> sro2syllabics('Maskêkosihk tireyl')
-    'ᒪᐢᑫᑯᓯᕽ ᑎᕒᐁᕀᓬ'
+    'ᒪᐢᑫᑯᓯᕽ ᑎᕒᐁᐩᓬ'
 
     Roman full-stops/periods (".") are converted into syllabics full-stops:
 
@@ -524,7 +529,7 @@ assert len(syllabics2sro_lookup) == len(sro2syllabics_lookup)
 # Add alternate and "look-alike" forms:
 syllabics2sro_lookup.update(
     {
-        # Some communities use the ᐝ symbol instead of ᕀ for the y-final.
+        # Some communities use the ᐝ symbol instead of ᐩ for the y-final.
         # See:
         # https://en.wikipedia.org/w/index.php?title=Plains_Cree&oldid=848160114#Canadian_aboriginal_syllabics
         # for an explanation of this special y-final.
@@ -534,7 +539,8 @@ syllabics2sro_lookup.update(
         # Look-alikes characters:
         "\N{CANADIAN SYLLABICS T}": "m",  # ᑦ looks like ᒼ or "m"
         "\N{CANADIAN SYLLABICS SAYISI YI}": "hk",  # ᕁ looks like ᕽ or "hk"
-        "\N{CANADIAN SYLLABICS FINAL PLUS}": "y",  # ᐩ looks like ᕀ or "y"
+        # See: https://github.com/UAlbertaALTLab/nehiyawewin-syllabics/issues/2
+        "\N{CANADIAN SYLLABICS WEST-CREE Y}": "y",  # ᕀ looks like ᐩ or "y"
         # Convert NNBSP within syllabics to hyphens to support round-trip
         # conversion between syllabics and SRO.
         "\N{NARROW NO-BREAK SPACE}": "-",
@@ -675,13 +681,21 @@ def syllabics2sro(syllabics: str, produce_macrons=False) -> str:
     Some syllabics converters produce erroneous yet very similar looking
     characters. ``syllabics2sro()`` knows the following look-alike characters:
 
-     ================================= ==================================
-      Look-alike                        Correct character
-     ================================= ==================================
-      ᐩ CANADIAN SYLLABICS FINAL PLUS   ᕀ CANADIAN SYLLABICS WEST-CREE Y
-      ᑦ CANADIAN SYLLABICS T            ᒼ CANADIAN SYLLABICS WEST-CREE M
-      ᕁ CANADIAN SYLLABICS SAYISI YI    ᕽ CANADIAN SYLLABICS HK
-     ================================= ==================================
+     ================================== ==================================
+      Look-alike                         Correct character
+     ================================== ==================================
+      ᕀ CANADIAN SYLLABICS WEST-CREE Y   ᐩ CANADIAN SYLLABICS FINAL PLUS
+      ᑦ CANADIAN SYLLABICS T             ᒼ CANADIAN SYLLABICS WEST-CREE M
+      ᕁ CANADIAN SYLLABICS SAYISI YI     ᕽ CANADIAN SYLLABICS HK
+     ================================== ==================================
+
+    Note: although \<U+1540 CANADIAN WEST-CREE Y\> is named as if it is the
+    correct Y final, writers prefer  \<U+1429 CANADIAN SYLLABICS FINAL PLUS\>.
+    Both are in the shape of a plus sign, but FINAL PLUS is often rendered
+    similarly to other finals, small, and above the center line, whereas
+    WEST-CREE Y is rendered centered to other syllabics. Having all finals
+    render small and above the centre line is preferable from most Cree
+    writers I surveyed.
 
     ``syllabics2sro()`` automatically interprets erroneous look-alikes as their
     visually equivalent characters.
